import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_system/senior_design_system.dart';
import '../page_wrapper.dart';
import '../panel.dart';

class SquareButtonsMenuExample extends StatefulWidget {
  const SquareButtonsMenuExample({Key? key}) : super(key: key);

  @override
  _SquareButtonsMenuExampleState createState() => _SquareButtonsMenuExampleState();
}

class _SquareButtonsMenuExampleState extends State<SquareButtonsMenuExample> {
  void showSnackBar({
    required BuildContext context,
    required String message,
  }) {
    final scaffold = ScaffoldMessenger.of(context);
    scaffold.showSnackBar(
      SnackBar(
        content: Text('Opção "$message" selecionada'),
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Square Buttons Menu Example',
      content: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.all(16.0),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.stretch,
            children: [
              Panel(
                title: 'In line',
                content: Center(
                  child: SeniorSquareButtonsMenu(
                    items: [
                      SeniorSquareButtonsMenuItemData(
                        onTap: (){
                          showSnackBar(
                            context: context,
                            message: 'Minha equipe',
                          );
                        },
                        icon: FontAwesomeIcons.users,
                        text: 'Minha equipe',
                        type: SeniorSquareButtonsMenuItemType.primary,
                      ),
                      SeniorSquareButtonsMenuItemData(
                        onTap: (){
                          showSnackBar(
                            context: context,
                            message: 'Meus feedbacks',
                          );
                        },
                        icon: FontAwesomeIcons.exchangeAlt,
                        text: 'Meus feedbacks',
                        type: SeniorSquareButtonsMenuItemType.secondary,
                      ),
                      SeniorSquareButtonsMenuItemData(
                        onTap: (){
                          showSnackBar(
                            context: context,
                            message: 'Períodos em aberto',
                          );
                        },
                        icon: FontAwesomeIcons.calendar,
                        text: 'Períodos em aberto',
                        type: SeniorSquareButtonsMenuItemType.secondary,
                      ),
                      SeniorSquareButtonsMenuItemData(
                        onTap: (){
                          showSnackBar(
                            context: context,
                            message: 'Novo atalho',
                          );
                        },
                        icon: FontAwesomeIcons.plus,
                        text: 'Novo atalho',
                        type: SeniorSquareButtonsMenuItemType.ghost,
                      ),
                    ],
                  ),
                ),
              ),
              Panel(
                title: 'Grid',
                content: Center(
                  child: SeniorSquareButtonsMenu.grid(
                    items: [
                      SeniorSquareButtonsMenuItemData(
                        onTap: (){
                          showSnackBar(
                            context: context,
                            message: 'Minha equipe',
                          );
                        },
                        icon: FontAwesomeIcons.users,
                        text: 'Minha equipe',
                        type: SeniorSquareButtonsMenuItemType.primary,
                      ),
                      SeniorSquareButtonsMenuItemData(
                        onTap: (){
                          showSnackBar(
                            context: context,
                            message: 'Meus feedbacks',
                          );
                        },
                        icon: FontAwesomeIcons.exchangeAlt,
                        text: 'Meus feedbacks',
                        type: SeniorSquareButtonsMenuItemType.secondary,
                      ),
                      SeniorSquareButtonsMenuItemData(
                        onTap: (){
                          showSnackBar(
                            context: context,
                            message: 'Períodos em aberto',
                          );
                        },
                        icon: FontAwesomeIcons.calendar,
                        text: 'Períodos em aberto',
                        type: SeniorSquareButtonsMenuItemType.secondary,
                      ),
                      SeniorSquareButtonsMenuItemData(
                        onTap: (){
                          showSnackBar(
                            context: context,
                            message: 'Meus documentos',
                          );
                        },
                        icon: FontAwesomeIcons.file,
                        text: 'Meus documentos',
                        type: SeniorSquareButtonsMenuItemType.secondary,
                      ),
                      SeniorSquareButtonsMenuItemData(
                        onTap: (){
                          showSnackBar(
                            context: context,
                            message: 'Registros de ponto',
                          );
                        },
                        icon: FontAwesomeIcons.clock,
                        text: 'Registros de ponto',
                        type: SeniorSquareButtonsMenuItemType.secondary,
                      ),
                      SeniorSquareButtonsMenuItemData(
                        onTap: (){
                          showSnackBar(
                            context: context,
                            message: 'Novo atalho',
                          );
                        },
                        icon: FontAwesomeIcons.plus,
                        text: 'Novo atalho',
                        type: SeniorSquareButtonsMenuItemType.ghost,
                      ),
                    ],
                  ),
                ),
              ),
              Panel(
                title: 'Grid reduzida',
                content: Center(
                  child: SeniorSquareButtonsMenu.grid(
                    crossAxisCount: 9,
                    items: [
                      SeniorSquareButtonsMenuItemData(
                        onTap: (){
                          showSnackBar(
                            context: context,
                            message: 'Minha equipe',
                          );
                        },
                        icon: FontAwesomeIcons.users,
                        text: 'Minha equipe',
                        type: SeniorSquareButtonsMenuItemType.primary,
                      ),
                      SeniorSquareButtonsMenuItemData(
                        onTap: (){
                          showSnackBar(
                            context: context,
                            message: 'Meus feedbacks',
                          );
                        },
                        icon: FontAwesomeIcons.exchangeAlt,
                        text: 'Meus feedbacks',
                        type: SeniorSquareButtonsMenuItemType.secondary,
                      ),
                      SeniorSquareButtonsMenuItemData(
                        onTap: (){
                          showSnackBar(
                            context: context,
                            message: 'Períodos em aberto',
                          );
                        },
                        icon: FontAwesomeIcons.calendar,
                        text: 'Períodos em aberto',
                        type: SeniorSquareButtonsMenuItemType.secondary,
                      ),
                      SeniorSquareButtonsMenuItemData(
                        onTap: (){
                          showSnackBar(
                            context: context,
                            message: 'Meus documentos',
                          );
                        },
                        icon: FontAwesomeIcons.file,
                        text: 'Meus documentos',
                        type: SeniorSquareButtonsMenuItemType.secondary,
                      ),
                      SeniorSquareButtonsMenuItemData(
                        onTap: (){
                          showSnackBar(
                            context: context,
                            message: 'Registros de pontos',
                          );
                        },
                        icon: FontAwesomeIcons.clock,
                        text: 'Registros de pontos',
                        type: SeniorSquareButtonsMenuItemType.secondary,
                      ),
                      SeniorSquareButtonsMenuItemData(
                        onTap: (){
                          showSnackBar(
                            context: context,
                            message: 'Configurações',
                          );
                        },
                        icon: FontAwesomeIcons.cog,
                        text: 'Configurações',
                        type: SeniorSquareButtonsMenuItemType.secondary,
                      ),
                      SeniorSquareButtonsMenuItemData(
                        onTap: (){
                          showSnackBar(
                            context: context,
                            message: 'Minhas atividades',
                          );
                        },
                        icon: FontAwesomeIcons.chartLine,
                        text: 'Minhas atividades',
                        type: SeniorSquareButtonsMenuItemType.secondary,
                      ),
                      SeniorSquareButtonsMenuItemData(
                        onTap: (){
                          showSnackBar(
                            context: context,
                            message: 'Meus favoritos',
                          );
                        },
                        icon: FontAwesomeIcons.star,
                        text: 'Meus favoritos',
                        type: SeniorSquareButtonsMenuItemType.secondary,
                      ),
                      SeniorSquareButtonsMenuItemData(
                        onTap: (){
                          showSnackBar(
                            context: context,
                            message: 'Novo atalho',
                          );
                        },
                        icon: FontAwesomeIcons.plus,
                        text: 'Novo atalho',
                        type: SeniorSquareButtonsMenuItemType.ghost,
                      ),
                    ],
                  ),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
