import 'package:flutter/material.dart';
import 'package:senior_design_tokens/tokens/senior_colors.dart';

class SeniorColorfulHeaderStructure extends StatefulWidget {
  const SeniorColorfulHeaderStructure({
    Key? key,
    required this.title,
    required this.body,
    required this.controller,
    this.leading,
    this.actions,
    this.hasTopPadding = false,
    this.colors,
  }) : super(
          key: key,
        );

  final Widget title;
  final Widget? leading;
  final List<Widget>? actions;
  final Widget body;
  final bool hasTopPadding;
  final List<Color>? colors;
  final ScrollController controller;

  @override
  State<SeniorColorfulHeaderStructure> createState() =>
      _SeniorColorfulHeaderStructureState();
}

class _SeniorColorfulHeaderStructureState
    extends State<SeniorColorfulHeaderStructure> {
  bool isAppBarEnabled = true;
  static const appBarOffsetLimit = 25;

  @override
  Widget build(BuildContext context) {
    return Container(
      decoration: BoxDecoration(
        gradient: LinearGradient(
          colors: widget.colors ?? SeniorColors.primaryGradientColors,
        ),
      ),
      child: NestedScrollView(
        controller: widget.controller
          ..addListener(() {
            if (widget.controller.offset > appBarOffsetLimit &&
                isAppBarEnabled) {
              setState(
                () {
                  isAppBarEnabled = false;
                },
              );
            } else if (widget.controller.offset <= appBarOffsetLimit &&
                !isAppBarEnabled) {
              setState(
                () {
                  isAppBarEnabled = true;
                },
              );
            }
          }),
        headerSliverBuilder: (
          BuildContext context,
          bool innerBoxIsScrolled,
        ) {
          return <Widget>[
            isAppBarEnabled
                ? SliverAppBar(
                    pinned: true,
                    leading: widget.leading ?? SizedBox.shrink(),
                    elevation: 0,
                    backgroundColor: Colors.transparent,
                    actions: widget.actions,
                    title: widget.title,
                    forceElevated: innerBoxIsScrolled,
                  )
                : SliverToBoxAdapter(
                    child: Container(
                      height: 70,
                    ),
                  )
          ];
        },
        body: AnimatedContainer(
          duration: Duration(
            milliseconds: 200,
          ),
          padding: EdgeInsets.only(
            top: widget.hasTopPadding ? 35 : 0,
          ),
          decoration: BoxDecoration(
            borderRadius: BorderRadius.only(
              topLeft: Radius.circular(
                isAppBarEnabled ? 35 : 0,
              ),
              topRight: Radius.circular(
                isAppBarEnabled ? 35 : 0,
              ),
            ),
            color: Colors.white,
          ),
          child: widget.body,
        ),
      ),
    );
  }
}
